@@ -2,9 +2,7 @@ require 5.006;
 use strict;
 use warnings;
 package Email::Valid;
-{
-  $Email::Valid::VERSION = '1.191';
-}
+$Email::Valid::VERSION = '1.193';
 # ABSTRACT: Check validity of Internet email addresses
 our (
   $RFC822PAT,
@@ -19,6 +17,7 @@ use File::Spec;
 use Scalar::Util 'blessed';
 
 our %AUTOLOAD = (
+  allow_ip => 1,
   fqdn     => 1,
   fudge    => 1,
   mxcheck  => 1,
@@ -147,11 +146,14 @@ sub _net_dns_query {
 
   my $packet = $Resolver->send($host, 'MX') or croak $Resolver->errorstring;
   if ($packet->header->ancount) {
-    my $mx = ($packet->answer)[0]->exchange;
-    if ($mx eq '.' or $mx eq '') {
-      return $self->details('mx'); # Null MX
-    } else {
-      return 1;
+    my @mx_entries = grep { $_->{'type'} eq 'MX' } $packet->answer;
+    if(@mx_entries) {
+        my $mx = ($mx_entries[0])->exchange;
+        if ($mx eq '.' or $mx eq '') {
+          return $self->details('mx'); # Null MX
+        } else {
+          return 1;
+        }
     }
   }
 
@@ -497,17 +499,227 @@ $RFC822PAT =~ s/\n//g;
 
 1;
 
+
+#pod =head1 SYNOPSIS
+#pod
+#pod   use Email::Valid;
+#pod   my $address = Email::Valid->address('maurice@hevanet.com');
+#pod   print ($address ? 'yes' : 'no');
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This module determines whether an email address is well-formed, and
+#pod optionally, whether a mail host exists for the domain.
+#pod
+#pod Please note that there is no way to determine whether an
+#pod address is deliverable without attempting delivery (for details, see
+#pod perlfaq 9).
+#pod
+#pod =head1 PREREQUISITES
+#pod
+#pod This module requires perl 5.004 or later and the Mail::Address module.
+#pod Either the Net::DNS module or the nslookup utility is required
+#pod for DNS checks.  The Net::Domain::TLD module is required to check the
+#pod validity of top level domains.
+#pod
+#pod =head1 METHODS
+#pod
+#pod   Every method which accepts an <ADDRESS> parameter may
+#pod   be passed either a string or an instance of the Mail::Address
+#pod   class.  All errors raise an exception.
+#pod
+#pod =over 4
+#pod
+#pod =item new ( [PARAMS] )
+#pod
+#pod This method is used to construct an Email::Valid object.
+#pod It accepts an optional list of named parameters to
+#pod control the behavior of the object at instantiation.
+#pod
+#pod The following named parameters are allowed.  See the
+#pod individual methods below of details.
+#pod
+#pod  -mxcheck
+#pod  -tldcheck
+#pod  -fudge
+#pod  -fqdn
+#pod  -allow_ip
+#pod  -local_rules
+#pod
+#pod =item mx ( <ADDRESS>|<DOMAIN> )
+#pod
+#pod This method accepts an email address or domain name and determines
+#pod whether a DNS record (A or MX) exists for it.
+#pod
+#pod The method returns true if a record is found and undef if not.
+#pod
+#pod Either the Net::DNS module or the nslookup utility is required for
+#pod DNS checks.  Using Net::DNS is the preferred method since error
+#pod handling is improved.  If Net::DNS is available, you can modify
+#pod the behavior of the resolver (e.g. change the default tcp_timeout
+#pod value) by manipulating the global Net::DNS::Resolver instance stored in
+#pod $Email::Valid::Resolver.
+#pod
+#pod =item rfc822 ( <ADDRESS> )
+#pod
+#pod This method determines whether an address conforms to the RFC822
+#pod specification (except for nested comments).  It returns true if it
+#pod conforms and undef if not.
+#pod
+#pod =item fudge ( <TRUE>|<FALSE> )
+#pod
+#pod Specifies whether calls to address() should attempt to correct
+#pod common addressing errors.  Currently, this results in the removal of
+#pod spaces in AOL addresses, and the conversion of commas to periods in
+#pod Compuserve addresses.  The default is false.
+#pod
+#pod =item allow_ip ( <TRUE>|<FALSE> )
+#pod
+#pod Specifies whether a "domain literal" is acceptable as the domain part.  That
+#pod means addresses like:  C<rjbs@[1.2.3.4]>
+#pod
+#pod The checking for the domain literal is stricter than the RFC and looser than
+#pod checking for a valid IP address, I<but this is subject to change>.
+#pod
+#pod The default is true.
+#pod
+#pod =item fqdn ( <TRUE>|<FALSE> )
+#pod
+#pod Species whether addresses passed to address() must contain a fully
+#pod qualified domain name (FQDN).  The default is true.
+#pod
+#pod B<Please note!>  FQDN checks only occur for non-domain-literals.  In other
+#pod words, if you have set C<allow_ip> and the address ends in a bracketed IP
+#pod address, the FQDN check will not occur.
+#pod
+#pod =item tld ( <ADDRESS> )
+#pod
+#pod This method determines whether the domain part of an address is in a
+#pod recognized top-level domain.
+#pod
+#pod B<Please note!>  TLD checks only occur for non-domain-literals.  In other
+#pod words, if you have set C<allow_ip> and the address ends in a bracketed IP
+#pod address, the TLD check will not occur.
+#pod
+#pod =item local_rules ( <TRUE>|<FALSE> )
+#pod
+#pod Specifies whether addresses passed to address() should be tested
+#pod for domain specific restrictions.  Currently, this is limited to
+#pod certain AOL restrictions that I'm aware of.  The default is false.
+#pod
+#pod =item mxcheck ( <TRUE>|<FALSE> )
+#pod
+#pod Specifies whether addresses passed to address() should be checked
+#pod for a valid DNS entry.  The default is false.
+#pod
+#pod =item tldcheck ( <TRUE>|<FALSE> )
+#pod
+#pod Specifies whether addresses passed to address() should be checked
+#pod for a valid top level domains.  The default is false.
+#pod
+#pod =item address ( <ADDRESS> )
+#pod
+#pod This is the primary method which determines whether an email
+#pod address is valid.  It's behavior is modified by the values of
+#pod mxcheck(), tldcheck(), local_rules(), fqdn(), and fudge().  If the address
+#pod passes all checks, the (possibly modified) address is returned as
+#pod a string.  Otherwise, the undefined value is returned.
+#pod In a list context, the method also returns an instance of the
+#pod Mail::Address class representing the email address.
+#pod
+#pod =item details ()
+#pod
+#pod If the last call to address() returned undef, you can call this
+#pod method to determine why it failed.  Possible values are:
+#pod
+#pod  rfc822
+#pod  localpart
+#pod  local_rules
+#pod  fqdn
+#pod  mxcheck
+#pod  tldcheck
+#pod
+#pod If the class is not instantiated, you can get the same information
+#pod from the global $Email::Valid::Details.
+#pod
+#pod =back
+#pod
+#pod =head1 EXAMPLES
+#pod
+#pod Let's see if the address 'maurice@hevanet.com' conforms to the
+#pod RFC822 specification:
+#pod
+#pod   print (Email::Valid->address('maurice@hevanet.com') ? 'yes' : 'no');
+#pod
+#pod Additionally, let's make sure there's a mail host for it:
+#pod
+#pod   print (Email::Valid->address( -address => 'maurice@hevanet.com',
+#pod                                 -mxcheck => 1 ) ? 'yes' : 'no');
+#pod
+#pod Let's see an example of how the address may be modified:
+#pod
+#pod   $addr = Email::Valid->address('Alfred Neuman <Neuman @ foo.bar>');
+#pod   print "$addr\n"; # prints Neuman@foo.bar
+#pod
+#pod Now let's add the check for top level domains:
+#pod
+#pod   $addr = Email::Valid->address( -address => 'Neuman@foo.bar',
+#pod                                  -tldcheck => 1 );
+#pod   print "$addr\n"; # doesn't print anything
+#pod
+#pod Need to determine why an address failed?
+#pod
+#pod   unless(Email::Valid->address('maurice@hevanet')) {
+#pod     print "address failed $Email::Valid::Details check.\n";
+#pod   }
+#pod
+#pod If an error is encountered, an exception is raised.  This is really
+#pod only possible when performing DNS queries.  Trap any exceptions by
+#pod wrapping the call in an eval block:
+#pod
+#pod   eval {
+#pod     $addr = Email::Valid->address( -address => 'maurice@hevanet.com',
+#pod                                    -mxcheck => 1 );
+#pod   };
+#pod   warn "an error was encountered: $@" if $@;
+#pod
+#pod =head1 CREDITS
+#pod
+#pod Significant portions of this module are based on the ckaddr program
+#pod written by Tom Christiansen and the RFC822 address pattern developed
+#pod by Jeffrey Friedl.  Neither were involved in the construction of this
+#pod module; all errors are mine.
+#pod
+#pod Thanks very much to the following people for their suggestions and
+#pod bug fixes:
+#pod
+#pod   Otis Gospodnetic <otis@DOMINIS.com>
+#pod   Kim Ryan <kimaryan@ozemail.com.au>
+#pod   Pete Ehlke <pde@listserv.music.sony.com>
+#pod   Lupe Christoph
+#pod   David Birnbaum
+#pod   Achim
+#pod   Elizabeth Mattijsen (liz@dijkmat.nl)
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod Mail::Address, Net::DNS, Net::Domain::TLD, perlfaq9
+#pod
+#pod =cut
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Email::Valid - Check validity of Internet email addresses
 
 =head1 VERSION
 
-version 1.191
+version 1.193
 
 =head1 SYNOPSIS
 
